@@ -1,7 +1,7 @@
 # -*- perl -*-
 
 #
-# $Id: Tree.pm,v 1.12 2003/01/29 11:57:22 eserte Exp $
+# $Id: Tree.pm,v 1.16 2003/02/10 22:35:14 eserte Exp $
 # Author: Slaven Rezic
 #
 # Copyright (C) 2001 Slaven Rezic. All rights reserved.
@@ -54,7 +54,7 @@ in a tree.
 
 use strict;
 use vars qw($VERSION @ISA @POD);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.16 $ =~ /(\d+)\.(\d+)/);
 
 use base 'Tk::Tree';
 
@@ -66,6 +66,16 @@ Construct Tk::Widget 'PodTree';
 
 BEGIN { @POD = @INC }
 
+BEGIN {  # Make a DEBUG constant very first thing...
+  if(defined &DEBUG) {
+  } elsif(($ENV{'TKPODDEBUG'} || '') =~ m/^(\d+)/) { # untaint
+    eval("sub DEBUG () {$1}");
+    die "WHAT? Couldn't eval-up a DEBUG constant!? $@" if $@;
+  } else {
+    *DEBUG = sub () {0};
+  }
+}
+
 ######################################################################
 use Class::Struct;
 struct '_PodEntry' => [
@@ -100,6 +110,15 @@ sub Populate {
     $args->{-separator} = "/";
 
     my $show_command = sub {
+	my($w, $cmd, $ent) = @_;
+
+	my $data = $w->info('data', $ent);
+	if ($data) {
+	    $w->Callback($cmd, $w, $data);
+	}
+    };
+
+    my $show_command_mouse = sub {
 	my $w = shift;
 	my $cmd = shift || '-showcommand';
 
@@ -113,17 +132,30 @@ sub Populate {
 	    return;
 	}
 
-	my $data = $w->info('data', $ent);
-	if ($data) {
-	    $w->Callback($cmd, $w, $data);
-	}
+	$show_command->($w, $cmd, $ent);
     };
 
-    foreach (qw/1 space Return/) {
-	$w->bind("<$_>" => sub { $show_command->(shift) });
+    my $show_command_key = sub {
+	my $w = shift;
+	my $cmd = shift || '-showcommand';
+
+	my($ent) = $w->selectionGet;
+	return unless (defined $ent and length $ent);
+
+	if ($w->info('children', $ent)) {
+	    $w->open($ent);
+	}
+
+	$show_command->($w, $cmd, $ent);
+    };
+
+    $w->bind("<1>" => sub { $show_command_mouse->(shift) });
+    foreach (qw/space Return/) {
+  	$w->bind("<$_>" => sub { $show_command_key->(shift) });
     }
+
     foreach (qw/2 Shift-1/) {
-	$w->bind("<$_>" => sub { $show_command->(shift, '-showcommand2') });
+	$w->bind("<$_>" => sub { $show_command_mouse->(shift, '-showcommand2') });
     }
 
     $w->SUPER::Populate($args);
@@ -208,6 +240,7 @@ if ($args{-cpan}) { $usecache = 0 }
     foreach (['perl',   'Perl language'],
 	     ['pragma', 'Pragmata'],
 	     ['mod',    'Modules'],
+	     ['script', 'Scripts'],
 	     keys %pods,
 	    ) {
 	my($category, $title) = (ref $_ ? @$_ : ($_, $_));
@@ -217,21 +250,17 @@ if ($args{-cpan}) { $usecache = 0 }
 
 	my $hash = $pods{$category};
 	foreach my $pod (sort keys %$hash) {
-	    next if $pod =~ /\./;#XXX
+#XXX del???	    next if $pod =~ /\./;#XXX
 
 	    my $treepath = "$category/$pod";
 	    (my $title = $pod) =~ s|/|::|g;
-#warn "$pod $hash->{$pod} $treepath\n";
 	    $w->_add_parents($treepath);
 
-#  	    my $is = Tk::Pod::FindPods::is_site_module($hash->{$pod})
-#  		     ? $w->{SiteIS}
-#  		     : $w->{CoreIS};
 	    my $loc = Tk::Pod::FindPods::module_location($hash->{$pod});
 	    my $is = $w->{Style}{$loc};
 	    my @entry_args = ($treepath,
 			      -text => $title,
-			      -data => _PodEntry->create($hash->{$pod}), #{File => $hash->{$pod}},
+			      -data => _PodEntry->create($hash->{$pod}),
 			      ($is ? (-style => $is) : ()),
 			     );
 	    if ($w->info('exists', $treepath)) {
@@ -300,10 +329,16 @@ subtrees to make the C<$path> visible, if necessary.
 
 sub SeePath {
     my($w,$path) = @_;
+    if ($^O eq 'MSWin32') {
+	$path =~ s/\\/\//g;
+	$path = lc $path;
+    }
+    DEBUG and warn "Call SeePath with $path\n";
     return if !$w->Filled; # XXX better solution!
     foreach my $category (keys %pods) {
 	foreach my $pod (keys %{ $pods{$category} }) {
 	    my $podpath = $pods{$category}->{$pod};
+	    $podpath = lc $podpath if $^O eq 'MSWin32'; # XXX should be really File::Spec->is_case_tolerant
 	    if ($path eq $podpath) {
 		my $treepath = "$category/$pod";
 		$w->open($treepath);
@@ -316,6 +351,7 @@ sub SeePath {
 	    }
 	}
     }
+    DEBUG and warn "SeePath: cannot find $path in tree\n";
     0;
 }
 
